@@ -2,9 +2,9 @@ import time
 import unittest
 import logging
 logger = logging.getLogger()
-from monagent.common.exceptions import UnknownValue, CheckException, Infinity
-from monagent.collector.checks import Check
-from monagent.common.aggregator import MetricsAggregator
+from monasca_agent.common.exceptions import UnknownValue, CheckException, Infinity
+from monasca_agent.collector.checks import Check
+from monasca_agent.common.aggregator import MetricsAggregator
 
 
 class TestCore(unittest.TestCase):
